<?php



/*
	Required files
	----------------------------
*/
require get_template_directory() . '/inc/breadcrumbs.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/widgets.php';



/*
	Enqueue scripts and styles
	---------------------------------
*/
function ghost_lite_styles_scripts_load() {

	// styles
	wp_enqueue_style( 'ghost-lite-style', get_stylesheet_uri() );
	wp_enqueue_style( 'ghost-lite-main-style', get_template_directory_uri() . '/css/main.css', array(), '1.0.0', 'all' );
	wp_enqueue_style( 'ghost-lite-fonts', get_template_directory_uri() . '/css/fonts.css', array(), '1.0.0', 'all' );

	if ( get_theme_mod( 'ghost_enable_custom_font_setting', 'no' ) == 'yes' ) {
		wp_enqueue_style(
			'ghost-lite-custom-fonts',
			esc_url( get_theme_mod(
				'ghost_main_font_url_setting',
				'https://fonts.googleapis.com/css?family=Open+Sans:400,400i,600|Oswald:400,600&display=swap'
			))
		);
		$fontname_body = esc_attr(str_replace(array('"', '\''), '', get_theme_mod( 'ghost_main_font_name_setting', "'Open Sans', sans-serif" )));
		$fontname_headings = esc_attr(str_replace(array('"', '\''), '', get_theme_mod( 'ghost_heading_font_name_setting', "'Oswald', sans-serif" )));
	} else {
		$fontname_body = "'montserrat', Arial, sans-serif";
		$fontname_headings = "'montserrat', Arial, sans-serif";
	}

	$main__color = esc_attr(get_theme_mod( 'ghost_main_color_setting', '#ffc222' ));

	wp_add_inline_style( 'ghost-lite-main-style', '
		.text__accent,.article__container article .post__content ul:not(.wp-block-gallery) li::before,.article__container .comments-area .comment-form p .required,.article__container .comments-area .comment-form p.comment-form-cookies-consent label::after,.ghost__contact__form input[type="checkbox"] ~ label::after
		{
			color: '. $main__color .';
		}
		.btn.ghost__flat,.cta.flat,.section__title.has__divider::after,.article__container article .post__content blockquote.wp-block-quote cite::before,.single__social.social__email,.ghost__contact__form .custom__select.active::before,.ghost__contact__form .custom__select.active::after,.screen-reader-text.skip-link:focus
		{
			background-color: '. $main__color .';
		}
		.btn.ghost__flat,.btn.ghost__glass,.search__container button,.article__container article .post__content blockquote.wp-block-quote,.article__container article .post__content figure.wp-block-pullquote,.article__container .comments-area li.comment p,.ghost__contact__form .success
		{
			border-color: '. $main__color .';
		}
		body,input,textarea,button,select {
			font-family: '. $fontname_body .';
		}
		h1,h2,h3,h4,h5,h6,.widget-title,.header__inner__wrapper .logo a,.article__container .prev_and_next_post__container .prev_next__text strong {
			font-family: '. $fontname_headings .';
		}
		@media only screen and (min-width: 1025px) {
			a:hover,section.white .btn.ghost__glass,.search__trigger:hover .vissage-icon,.tab__headers li:hover:not(.active)
			{
				color: '. $main__color .';
			}
			.article__container article .img__wrapper,.article__container article .read__more:hover,.article__container .share__post__container.ghost__glass .single__social.social__email:hover,.form-submit input[type="submit"]:hover,.article__container .comments-area li.comment .comment-reply-link:hover,.card__item:hover::before,.widget_search input[type="submit"]:hover,.article__container.no__search__result button[type="submit"]:hover,.article__container .prev_and_next_post__container .prev_next__post__link:hover .vissage-icon,.article__container .prev_and_next_post__container .prev_next__post__link:hover .prev_next__text,.ghost__contact__form .custom__select .option_list li:hover
			{
				background-color: '. $main__color .';
			}
			.btn.ghost__white:hover,.widget_tag_cloud .tag-cloud-link:hover
			{
				border-color: '. $main__color .';
			}
			::-webkit-scrollbar-thumb {border-color: '. $main__color .';}
			::-moz-selection {background: '. $main__color .';}
			::selection {background: '. $main__color .';}
		}
		@media only screen and (max-width: 1024px) {
			.menu-item.menu-item-has-children.active > .mob_menu_arrow::before,.menu-item.menu-item-has-children.active > .mob_menu_arrow::after
			{
				background-color: '. $main__color .';
			}
		}
	' );

	wp_register_script( 'ghost-lite-main-script', get_template_directory_uri() . '/js/custom.js', array(), '1.0.0', true );
	wp_enqueue_script( 'ghost-lite-main-script' );

}
add_action('wp_enqueue_scripts', 'ghost_lite_styles_scripts_load');



/*
	Theme support
	---------------------------------
*/
add_action('after_setup_theme', function() {
	add_theme_support('post-thumbnails');
	add_theme_support('title-tag');
	add_theme_support('automatic-feed-links');
	add_theme_support('html5', array('comment-list', 'comment-form', 'search-form', 'gallery', 'caption'));
	add_theme_support('custom-logo', [ 'height' => 160,'width' => 292 ]);
});



/*
	Register menus and theme text domain
	----------------------------
*/
add_action('after_setup_theme', function() {

	register_nav_menus(array(
		'ghost-lite-main-menu'		=> esc_html__('Ghost main menu', 'ghost-lite'),
		'ghost-lite-404-menu'		=> esc_html__('404 page links menu', 'ghost-lite')
	));

	load_theme_textdomain( 'ghost-lite', get_template_directory() . '/languages' );

	add_theme_support( 'editor-styles' );
	add_editor_style( 'css/editor-styles.css' );

});



/*
	Excerpt
	----------------------------
*/
add_filter('excerpt_length', function( $length ) {
	if ( is_admin() ) {
		return $length;
	}
	return get_theme_mod( 'ghost_excerpt_length_setting', 25 );
});

add_filter('excerpt_more', function( $more_string ) {
	if ( is_admin() ) {
		return $more_string;
	}
	return esc_html(get_theme_mod( 'ghost_excerpt_read_more_setting', ' . . .' ));
});



/*
	Remove post pagination title
	----------------------------
*/
add_filter('navigation_markup_template', function( $template, $class ) {
	return '<nav class="navigation flx %1$s" role="navigation"><div class="nav-links">%3$s</div></nav> ';
}, 10, 2 );



/*
	Tags font size
	----------------------------
*/
add_filter('widget_tag_cloud_args', function( $args ) {
	$args['smallest']	= 9;
	$args['largest']	= 9;
	return $args;
});



/*
	Register Sidebar
	----------------------------
*/
add_action('widgets_init', function() {

	register_sidebar( array(
		'name'          => esc_html__( 'Main sidebar', 'ghost-lite' ),
		'id'            => 'ghost-lite-main-sidebar',
		'description'   => esc_html__( 'Main theme sidebar area', 'ghost-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<p class="widget-title">',
		'after_title'   => '</p>'
	) );

	for ( $i=1; $i<=4; $i++ ) {
		register_sidebar( array(
			'name'          => esc_html__('Footer ', 'ghost-lite') . $i,
			'id'            => 'ghost-lite-footer-sidebar-' . $i,
			'description'   => esc_html__('Footer widgets area ', 'ghost-lite') . $i,
			'before_widget' => '<div id="%1$s" class="widget %2$s footer-sidebar-' . $i . '">',
			'after_widget'  => '</div>',
			'before_title'  => '<p class="widget-title">',
			'after_title'   => '</p>'
		) );
	}

});



/*
	Change comment reply title tag from h3 to p
	----------------------------
*/
add_filter('comment_form_defaults', function( $defaults ){
	$defaults = array(
		'title_reply_before' => '<p id="reply-title" class="comment-reply-title">',
		'title_reply_after' => '</p>'
	);
	return $defaults;
});



/*
	Custom content width
	----------------------------
*/
if ( ! isset( $content_width ) ) $content_width = 750;



/*
	Remove tag & category prefix
	----------------------------
*/
add_filter('get_the_archive_title', function( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
    	$title = single_tag_title( '', false );
  	}
	return $title;
});




