<?php
/**
 * Recent posts with thumbnails
 *
 * @package Ghost
 */

class Ghost_Lite_Widget_Recent_Posts extends WP_Widget {

	public function __construct() {
		$widget_ops = array(
			'classname'                   => 'widget_recent_entries',
			'description'                 => __( 'Recent posts with thumbs and date.', 'ghost-lite' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct(
			'ghost-lite-recent-posts',
			__( 'Ghost recent Posts', 'ghost-lite' ),
			$widget_ops
		);
		$this->alt_option_name = 'widget_recent_entries';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'ghost-lite' );

		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number ) {
			$number = 5;
		}
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$rp = new WP_Query(
			apply_filters(
				'widget_posts_args',
				array(
					'posts_per_page'      => $number,
					'no_found_rows'       => true,
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
				),
				$instance
			)
		);

		if ( ! $rp->have_posts() ) {
			return;
		}
		?>
		<?php echo $args['before_widget']; ?>
		<?php
		if ( $title ) {
			echo $args['before_title'] . esc_html($title) . $args['after_title'];
		}
		?>
		<ul class="recent__post__list">
			<?php while ( $rp->have_posts() ) : $rp->the_post(); ?>

				<li class="flx">
					<?php if ( has_post_thumbnail() ) : ?>
						<a href="<?php the_permalink(); ?>" class="thumb">
							<?php the_post_thumbnail('thumbnail'); ?>
						</a>
					<?php endif; ?>	
					<div class="recent__post__info flx">
						<h4 class="recent__post__title">
							<a href="<?php the_permalink(); ?>" class="recent__post__link"><?php the_title(); ?></a>
						</h4>
						<?php if ( $show_date ) : ?>
							<time class="recent__posts__time">
								<?php echo esc_html(get_the_date()); ?>
							</time>
						<?php endif; ?>
						<a href="<?php the_permalink(); ?>#comments" class="recent__post__comments">
							<span class="vissage-icon vissage-conversation"></span><?php echo esc_html(get_comments_number()) ?>
						</a>
					</div>
				</li>

			<?php endwhile; wp_reset_postdata(); ?>
		</ul>
		<?php
		echo $args['after_widget'];
	}

	public function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['number']    = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		return $instance;
	}
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>">
				<?php esc_html_e( 'Title:', 'ghost-lite' ); ?>
			</label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>">
				<?php esc_html_e( 'Number of posts to show:', 'ghost-lite' ); ?>
			</label>
			<input class="tiny-text" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" size="3" />
		</p>

		<p>
			<input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_date' )); ?>" />
			<label for="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>">
				<?php esc_html_e( 'Display post date?', 'ghost-lite' ); ?>
			</label>
		</p>
		<?php
	}
}
